Module: Boolean

Included in:
FalseClass, TrueClass
Defined in:
lib/boolean.rb

Overview

Just a simple module to represent a boolean in Ruby, as it appears there's not much to know if an object is a boolean or not... So I'll use this occasion to override some native classes like suggested. src: https://stackoverflow.com/a/3028378/3612053